# FACT Geology and Mining
General geology of the world and main minerals deposits and mines (data from USGS).

---

[![GitLab License](https://img.shields.io/gitlab/license/fact%2Fdata%2FFACT_mine?gitlab_url=https%3A%2F%2Fgit.nilu.no&style=flat&color=orange)](https://www.gnu.org/licenses/old-licenses/gpl-2.0.html)
[![DOI](https://img.shields.io/badge/DOI-10.17605%2FOSF.IO%2F68YWE-blue?style=flat)](https://doi.org/10.17605/OSF.IO/68YWE)
[![Data License](https://img.shields.io/badge/data-CC%20BY%204.0-green)](https://creativecommons.org/licenses/by/4.0/legalcode.txt)

---


## Use
1. Through the command line:
```bash
docker pull registry.git.nilu.no/fact/data/fact_mine:latest
docker run -t -i --name fact_mine -e MARIADB_DATABASE=FACT_mine -e MYSQL_ROOT_PASSWORD=devops -p 3314:3306 -d registry.git.nilu.no/fact/data/fact_mine:0.1
```
2. Through a docker-compose file:
```yaml
version: '3.8'

services:
  fact_mine:
    image: registry.git.nilu.no/fact/data/fact_mine:latest
    container_name: fact_mine
    environment:
      MARIADB_DATABASE: FACT_mine
      MYSQL_ROOT_PASSWORD: devops
    ports:
      - "3314:3306"
    restart: unless-stopped
```
which could be executed with `docker-compose up fact_mine -d`.

The container makes available a MariaDB instance with the full database on airports and traffic **FACT_mine**. It is reachable on port 3314 of the localhost and the root password is 'devops'.


---
## Specifications
```
Table           |Size (MB)|Rows (#)|
----------------+---------+--------+
carbonatite     |     0.05|      60|
geology         |    36.92|    9143|
geometry_columns|     0.02|      14|
global_selected |     0.45|    2121|
laterite        |     0.05|     120|
nicrpge         |     5.04|   17954|
phosphate       |     0.35|    1187|
podchrome       |     0.27|    1045|
porcu           |     0.18|     690|
potash          |     0.26|     981|
ree             |     0.15|     577|
sedcu           |     0.21|     785|
sedexmvt        |     0.09|     240|
sedznpb         |     0.14|     506|
spatial_ref_sys |     0.02|       2|
vms             |     0.25|    1090|
```

![tables schema](FACT_mine.png "Tables in DB")

In table geology, there are 17 distinct types of geological era (including NULL):
```
era                             |
--------------------------------+
Cenozoic                        |
Mesozoic                        |
Paleozoic-Mesozoic              |
Paleozoic                       |
Mesozoic-Cenozoic               |
Precambrian                     |
Neoproterozoic                  |
Archean-Paleoproterozoic        |
Mesoproterozoic                 |
Paleoproterozoic                |
Archean                         |
Paleoproterozoic-Mesoproterozoic|
Mesoproterozoic-Neoproterozoic  |
Precambrian-Phanerozoic         |
Phanerozoic                     |
Proterozoic                     |
Eoarchean                       |
                                |
```
And there are 9 distinct values of rock type:
```
rxtyp                         |
------------------------------+
volcanic rocks                |
sedimentary rocks             |
intrusive rocks               |
crystalline metamorphic rocks |
sedimentary and volcanic rocks|
volcanic and intrusive rocks  |
ice                           |
tectonic rocks                |
unclassified rocks            |
                              |
```

**All spatial objects are converted to EPSG:4326.**

---
## Notes

### Geology
General geology of the world
https://mrdata.usgs.gov/geology/gscworld/
>GSC General geologic map of the world: Chorlton, L. B. (Compiler), 2007: Generalized Geology of the World: Bedrock Domains and Major Faults in GIS Format; Geological Survey of Canada, Open File 5529, 1 CD-ROM. 
https://doi.org/10.4095/223767

### Mineral deposits:
#### World phosphate mines, deposits, and occurrences
https://mrdata.usgs.gov/phosphate/
#### Podiform chromite deposits
https://mrdata.usgs.gov/podchrome/
#### Ni-Co laterite deposits of the world
https://mrdata.usgs.gov/laterite/
#### Rare earth element mines, deposits, and occurrences
https://mrdata.usgs.gov/ree/
#### Carbonatites of the world, explored deposits of Nb and REE
https://mrdata.usgs.gov/carbonatite/
#### PGE-Ni-Cr deposit and occurrence bibliographic database
https://mrdata.usgs.gov/nicrpge/
#### Sediment-hosted copper deposits of the world
https://mrdata.usgs.gov/sedcu/
#### Porphyry copper deposits of the world
https://mrdata.usgs.gov/porcu/
#### Mineral resource data for Mississippi Valley-Type and clastic-dominated sediment-hosted lead-zinc deposits
https://mrdata.usgs.gov/sedexmvt/
#### Sediment-hosted zinc-lead deposits of the world
https://mrdata.usgs.gov/sedznpb/
#### Volcanogenic massive sulfide deposits
https://mrdata.usgs.gov/vms/
#### Evaporite-related potash resources worldwide
https://mrdata.usgs.gov/potash/
#### Global distribution of selected mines, deposits, and districts of critical minerals
https://mrdata.usgs.gov/pp1802/

---
## Author
Riccardo Boero - ribo@nilu.no

## Licenses
All the code and the resulting docker images in this project are subject to:
- [GNU Generla Public License v2](https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).

The data is released under: 
- [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/) license.

The input data is licensed as:
- "Data available from U.S. Geological Survey, National Geospatial Program", [Copyrights and Credits](https://www.usgs.gov/information-policies-and-instructions/copyrights-and-credits).

## Citation
- Boero, Riccardo. 2024. “FACT Data: Geology and Mining.” OSF. [doi:10.17605/OSF.IO/68YWE](https://doi.org/10.17605/OSF.IO/68YWE). 

Part of the Fine scAle eConomic daTa - FACT project:
- Boero, Riccardo. 2024. “Fine scAle eConomic daTa - FACT.” OSF. [doi:10.17605/OSF.IO/PV4ZW](https://doi.org/10.17605/OSF.IO/PV4ZW). 

